# Linguist, an ultimate browser extension for translation

July 13, 2023 5 min read

The web browser is the most used program on any desktop. And many users regularly visit sites in foreign languages.

For such users, a browser extension for translation is a must-have tool. And I want to introduce you to Linguist — a browser extension for translation that I have been working on for the past few years.

## Features

Linguist supports full page translation, selected text translation, and translation of text in input fields.